@@ -1,5 +1,5 @@
 # Copyright (C) 2014 Science and Technology Facilities Council.
-# Copyright (C) 2015 East Asian Observatory.
+# Copyright (C) 2015-2017 East Asian Observatory.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -153,6 +153,7 @@ class MOCTool(object):
                 [radius 3600]
                 [unit (hour | deg | rad) (deg | rad)]
                 [format commented_header]
+                [inclusive]
 
         Units (if not specified) are assumed to be hours and degrees for ICRS
         coordinates and degrees for galactic coordinates.  The format, if not
@@ -173,6 +174,7 @@ class MOCTool(object):
         radius = 3600
         unit = None
         format_ = 'commented_header'
+        kwargs = {}
 
         while self.params:
             if self.params[-1] == 'order':
@@ -189,11 +191,14 @@ class MOCTool(object):
             elif self.params[-1] == 'format':
                 self.params.pop()
                 format_ = self.params.pop()
+            elif self.params[-1] == 'inclusive':
+                self.params.pop()
+                kwargs['inclusive'] = True
             else:
                 break
 
         coords = read_ascii_catalog(filename, format_=format_, unit=unit)
-        catalog_moc = catalog_to_moc(coords, radius, order)
+        catalog_moc = catalog_to_moc(coords, radius, order, **kwargs)
 
         if self.moc is None:
             self.moc = catalog_moc
@@ -243,12 +248,19 @@ class MOCTool(object):
             pymoctool ... --id 'New MOC identifier' --output new_moc.fits
         """
 
+        if self.moc is None:
+            self.moc = MOC()
+
         self.moc.id = self.params.pop()
 
     @command('--info', '-i')
     def display_info(self):
         """Display basic information about the running MOC."""
 
+        if self.moc is None:
+            print('No MOC information present')
+            return
+
         if self.moc.name is not None:
             print('Name:', self.moc.name)
         if self.moc.id is not None:
@@ -269,6 +281,9 @@ class MOCTool(object):
             pymoctool a.fits --intersection b.fits --output intersection.fits
         """
 
+        if self.moc is None:
+            raise CommandError('No MOC information present for intersection')
+
         filename = self.params.pop()
         self.moc = self.moc.intersection(MOC(filename=filename))
 
@@ -283,6 +298,9 @@ class MOCTool(object):
             pymoctool ... --name 'New MOC name' --output new_moc.fits
         """
 
+        if self.moc is None:
+            self.moc = MOC()
+
         self.moc.name = self.params.pop()
 
     @command('--normalize')
@@ -297,6 +315,9 @@ class MOCTool(object):
             pymoctool a.fits --normalize 10 --output a_10.fits
         """
 
+        if self.moc is None:
+            raise CommandError('No MOC information present for normalization')
+
         order = int(self.params.pop())
         self.moc.normalize(order)
 
@@ -304,6 +325,9 @@ class MOCTool(object):
     def write_moc(self):
         """Write the MOC to a given file."""
 
+        if self.moc is None:
+            raise CommandError('No MOC information present for output')
+
         filename = self.params.pop()
         self.moc.write(filename)
 
@@ -319,6 +343,9 @@ class MOCTool(object):
             pymoctool a.fits --subtract b.fits --output difference.fits
         """
 
+        if self.moc is None:
+            raise CommandError('No MOC information present for subtraction')
+
         filename = self.params.pop()
         self.moc -= MOC(filename=filename)
 
@@ -347,6 +374,9 @@ class MOCTool(object):
             pymoctool ... --plot [order <order>] [antialias <level>] [file <filename>] ...
         """
 
+        if self.moc is None:
+            raise CommandError('No MOC information present for plotting')
+
         from .plot import plot_moc
 
         order = self.moc.order
